USE master;
SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;
GO
--
--
-- Impression LCF SQL Server Install Script
-- Copyright 2006-2016 Logicdriven, LLC.  All rights reserved.
-- Last modified: 5 June 2016
--
--
-- PLEASE READ COMPLETLY BEFORE EXECUTING THIS SCRIPT
--
--
-- This script prepares an instance of SQL Server for use with Impression.  The script
-- performs the following actions:
--
--     1: Creates the Impression connector database (default name: 'impressionConnector').  
--        The connector database is used to store connection information for content databases 
--        and to manage end-user access rights to these databases.
--
--     2: Creates the SQL Server login for the connector database (default name/password values
--        are 'impression'/'impression').  This account is provided access to the connector and
--        is used by the Impression client software to access the connector database.  
--
--     3: Adds permissions to the connector database for the login created in Step 2.
--
--     4: Creates the following stored procedures:
--
--        Creates proc_NewImpressionProjectDatabase, that the Impression Connector Managment 
--        Tool (ICMT) uses to create new Impression content databases.  Note that the ICMT will 
--        prompt for the username/password of an SQL Server account (like 'sa') that has 
--        sufficient privileges to create content catalogs and users.
--
--        Creates proc_NewImpressionDBFromConsole, which can be used to create a new content 
--        database from the SQL Server console.
--
--        Creates proc_SetImpressionDBAccessRights, which can be used to set permissions on an
--        Impression content database for a specific login.
--
--
-- CUSTOMIZATION:
--
-- The name of the connector database and the username/password for the SQL Server login can be 
-- customized.  Change the SET statements for the variables @ConnectorDBName, @ConnectorUsername,
-- and @ConnectorPassword immediately following these comments to suit your requirements.
--
--
-- ERROR RECOVERY/REMOVAL:
--
-- If this script encounters an error during execution, some artifacts may be left on the server
-- preventing a successful re-execution, even if the original problem is resolved.  To remove all
-- objects created by this script, perform the following actions:
--
--     1: Delete the connector database (default name: 'impressionConnector').
--     2: Delete the SQL Login for the connector (default name: 'impression').
--
--
-- UPGRADING:
--
-- If you have already created a connector database on this machine using an older version of this
-- script, use the "Impression SQL Server Upgrade Script" instead of this one.
--
--
--


--
-- declare local variables (customize these values as desired)
--
DECLARE @ConnectorDBName nvarchar(128);
DECLARE @ConnectorUsername nvarchar(128);
DECLARE @ConnectorPassword nvarchar(128);

SET @ConnectorDBName = 'impressionConnector';
SET @ConnectorUsername = 'impression';
SET @ConnectorPassword = 'impression';


PRINT 'Impression SQL Server Install Script';
PRINT 'Execution started';
PRINT ' ';


--
-- create the connector database and structure (tables, keys/constraints, and indexes)
--
--
DECLARE @cSQL nvarchar(MAX);

PRINT 'Creating connector database ''' + @ConnectorDBName + '''';
SET @cSQL = 'CREATE DATABASE [' + @ConnectorDBName + ']';
EXECUTE(@cSQL);


PRINT 'Creating connector database structure';

SET @cSQL = 'CREATE TABLE [' + @ConnectorDBName + '].[dbo].[impressionConnectionHistory]('
	+ '	[username] [nvarchar](32) NOT NULL,'
	+ '	[machineName] [nvarchar](32) NOT NULL,'
	+ '	[machineIP] [nvarchar](32) NOT NULL,'
	+ '	[osVersion] [nvarchar](128) NULL,'
	+ '	[appVersion] [nvarchar](128) NULL,'
	+ '	[lastConnect] [datetime] NULL,'
	+ '	[lastCatalog] [nvarchar](32) NULL'
	+ ') ON [PRIMARY]';
EXECUTE(@cSQL);




SET @cSQL = 'CREATE TABLE  [' + @ConnectorDBName + '].[dbo].[impressionDBList]('
	+ '	[dbID] [int] IDENTITY(1,1) NOT NULL,'
	+ '	[dbTitle] [nvarchar](256) NOT NULL,'
	+ '	[dbCatalogName] [nvarchar](32) NOT NULL,'
	+ '	[username] [nvarchar](32) NOT NULL,'
	+ '	[password] [nvarchar](32) NOT NULL,'
	+ '	[dbDescription] [nvarchar](512) NULL'
	+ ') ON [PRIMARY]';
EXECUTE(@cSQL);

SET @cSQL = 'CREATE CLUSTERED INDEX [IX_impressionDBList] ON [' + @ConnectorDBName + '].[dbo].[impressionDBList]('
	+ ' [dbID], [dbTitle], [dbCatalogName], [username], [password]'
	+ ') WITH FILLFACTOR = 100 ON [PRIMARY]';
EXECUTE(@cSQL);




SET @cSQL = 'CREATE TABLE [' + @ConnectorDBName + '].[dbo].[impressionDBUserRights] ('
	+ ' [userID] [int] NOT NULL,'
	+ ' [dbID] [int] NOT NULL,'
	+ ' [rights] [int] NOT NULL'
	+ ' ) ON [PRIMARY]';
EXECUTE(@cSQL);

SET @cSQL = 'CREATE CLUSTERED INDEX [IX_impressionDBUserRights] ON [' + @ConnectorDBName + '].[dbo].[impressionDBUserRights]('
	+ ' [userID], [dbID], [rights]'
	+ ') WITH FILLFACTOR = 90 ON [PRIMARY]';
EXECUTE(@cSQL);

SET @cSQL = 'ALTER TABLE [' + @ConnectorDBName + '].[dbo].[impressionDBUserRights]'
	+ ' ADD CONSTRAINT [DF_impressionDBUserRights_admin] DEFAULT (0) FOR [rights]';
EXECUTE(@cSQL);



SET @cSQL = 'CREATE TABLE [' + @ConnectorDBName + '].[dbo].[impressionDBUsers] ('
	+ ' [userID] [int] IDENTITY (1, 1) NOT NULL,'
	+ ' [username] [nvarchar](32) NOT NULL,'
	+ ' [superUser] [bit] NOT NULL'
	+ ' ) ON [PRIMARY]';
EXECUTE(@cSQL);
  
SET @cSQL = 'CREATE CLUSTERED INDEX [IX_impressionDBUsers] ON [' + @ConnectorDBName + '].[dbo].[impressionDBUsers]('
	+ ' [username], [userID]'
	+ ') WITH FILLFACTOR = 90 ON [PRIMARY]';
EXECUTE(@cSQL);

SET @cSQL = 'ALTER TABLE [' + @ConnectorDBName + '].[dbo].[impressionDBUsers]'
	+ ' ADD CONSTRAINT [DF_impressionDBUsers_superUser] DEFAULT (0) FOR [superUser]';
EXECUTE(@cSQL);








--
-- create the SQL Server login (if necessary), then set permissions
--
--
IF NOT EXISTS(SELECT name FROM master.sys.server_principals WHERE name = @ConnectorUsername) BEGIN
	PRINT 'Creating connector user ''' + @ConnectorUsername + '''';
	SET @cSQL = 'CREATE LOGIN ' + @ConnectorUsername + ' WITH PASSWORD = ''' + @ConnectorPassword + ''', DEFAULT_DATABASE = [' + @ConnectorDBName + '];';
	EXECUTE(@cSQL);
END ELSE BEGIN
	PRINT 'Connector user ''' + @ConnectorUsername + ''' already exists.  Skipping creation';
	PRINT '    NOTE: Ensure that the connector user password is valid.';
END

PRINT 'Adding connector permissions';

SET @cSQL = 'USE [' + @ConnectorDBName + '];'
	+ 'EXECUTE sp_grantdbaccess ' + @ConnectorUsername + ',' + @ConnectorUsername;
EXECUTE(@cSQL);

SET @cSQL = 'USE [' + @ConnectorDBName + '];'
	+ ' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionConnectionHistory] TO [' + @ConnectorUsername + ']'
	+ ' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionDBList] TO [' + @ConnectorUsername + '] '
	+ ' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionDBUserRights] TO [' + @ConnectorUsername + '] '
	+ ' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionDBUsers] TO [' + @ConnectorUsername + '] '
EXECUTE(@cSQL);








--
-- create stored procedures
--
-- to create these procedures within a connector database defined as a variable
-- (@ConnectorDBName), we have to do a bit of slight-of-hand.  we use @cSQL to 
-- define the script, and then use another string variable, @execSQL, to execute 
-- the cSQL script using the newly created connector.  the @execSQL text is then 
-- executed here from the master catalog.
--
-- our @execSQL text will be the same, namely:
--
--     SET @execSQL = 'USE [' + @ConnectorDBName + ']; EXECUTE (''' + REPLACE(@cSQL, '''', '''''') + ''')';
--
-- where the REPLACE code ensure that the quotes in the script are properly escaped
--
-- 
DECLARE @execSQL nvarchar(MAX);
DECLARE @crlf nvarchar(2);
SET @crlf = CHAR(13) + CHAR(10); 




--
-- create proc_NewImpressionProjectDatabase stored procedure
--
--
PRINT 'creating proc_NewImpressionProjectDatabase';

SET @cSQL = CAST('' AS nvarchar(max))
+ 'CREATE PROCEDURE [dbo].[proc_NewImpressionProjectDatabase](@ProjectName nvarchar(50), @SQLLoginName nvarchar(50), @SQLLoginNamePassword as nvarchar(50)) AS' + @crlf
+ '-- proc_NewImpressionProjectDatabase' + @crlf
+ '--' + @crlf
+ '-- Impression Learning Content Framework' + @crlf
+ '-- Copyright 2006-2016 Logicdriven, LLC.  All rights reserved.' + @crlf
+ '--' + @crlf
+ '-- This procedure creates a new Impression-format content database.' + @crlf
+ '--' + @crlf
+ '-- PARAMETERS:' + @crlf
+ '--     @ProjectName          - catalog name of the new content database' + @crlf
+ '--     @SQLLoginName         - login to use to access the database.  if the login does' + @crlf
+ '--                             not exist, it will be created' + @crlf
+ '--     @SQLLoginNamePassword - password for @SQLLoginName. ignored if @SQLLoginName exists.' + @crlf
+ '--' + @crlf
+ '-- NOTES:' + @crlf
+ '--     - This procedure must be run with Administrator rights.' + @crlf
+ '--     - The ''sa'' account is incompatible with certain system procs.  ' + @crlf
+ '--       DO NOT use the ''sa'' account as the @SQLLoginName parameter.' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- initial prep. validate parameters, then create the database' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ 'SET NOCOUNT ON' + @crlf
+ 'DECLARE @cSQL nvarchar(MAX);' + @crlf
+ @crlf
+ @crlf
+ 'IF (LEN(LTRIM(@ProjectName)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''Catalog name cannot be blank.'', 16, 1);' + @crlf
+ '	RETURN;' + @crlf
+ 'END' + @crlf
+ 'IF (LEN(LTRIM(@SQLLoginName)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''SQL login name cannot be blank.'', 16, 1);' + @crlf
+ '	RETURN;' + @crlf
+ 'END' + @crlf
+ @crlf
+ 'IF (LEN(LTRIM(@SQLLoginNamePassword)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''SQL login password cannot be blank.'', 16, 1);' + @crlf
+ '	RETURN;' + @crlf
+ 'END' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ 'SET @cSQL = ''CREATE DATABASE ['' + @ProjectName + '']'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- create content database structure' + @crlf
+ '--' + @crlf
+ '-- after creating the database, we now go through table by table, adding' + @crlf
+ '-- the columns, keys, and indexes for each one' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ '-- impressionAutonumbers' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[impressionAutonumbers] (''' + @crlf
+ '	+ ''[nextNumber] [int] IDENTITY (1, 1) NOT NULL,''' + @crlf
+ '	+ ''[ignored] [int] NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionLessons' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[impressionLessons] (''' + @crlf
+ '	+ ''[lessonID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[lessonTitle] [nvarchar] (255) NOT NULL,''' + @crlf
+ '	+ ''[lessonIdentifier] [nvarchar] (255) NOT NULL,''' + @crlf
+ '	+ ''[parentID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[indentLevel] [int] NOT NULL,''' + @crlf
+ '	+ ''[sortPosition] [int] NOT NULL,''' + @crlf
+ '	+ ''[lessonType] [int] NOT NULL,''' + @crlf
+ '	+ ''[lessonProperties] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lessonData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[guideData] [nvarchar](max) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @ProjectName + ''].[dbo].[impressionLessons] WITH NOCHECK ADD CONSTRAINT [PK_impressionLessons] PRIMARY KEY CLUSTERED ([lessonID]) ON [PRIMARY];'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionMilestones' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[impressionMilestones] (''' + @crlf
+ '	+ ''[milestoneID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[lessonID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[savedBy] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[savedDate] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[milestoneProperties] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lessonData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[guideData] [nvarchar](max) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @ProjectName + ''].[dbo].[impressionMilestones] ADD CONSTRAINT [PK_impressionMilestones] PRIMARY KEY NONCLUSTERED ([milestoneID]) ON [PRIMARY];''' + @crlf
+ '	+ ''CREATE CLUSTERED INDEX [IX_lessonID-milestoneID] ON ['' + @ProjectName + ''].[dbo].[impressionMilestones]([lessonID], [milestoneID]) WITH FILLFACTOR = 80 ON [PRIMARY];''' + @crlf
+ '	+ ''CREATE INDEX [IX_milestoneID-lessonID] ON ['' + @ProjectName + ''].[dbo].[impressionMilestones]([milestoneID], [lessonID]) WITH FILLFACTOR = 80 ON [PRIMARY];'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionProjectProperties' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[impressionProjectProperties] (''' + @crlf
+ '	+ ''[propertyData] [nvarchar](max) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionUserLocks' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[impressionUserLocks] (''' + @crlf
+ '	+ ''[lessonID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[username] [nvarchar] (32) NOT NULL,''' + @crlf
+ '	+ ''[machineName] [nvarchar] (32) NOT NULL,''' + @crlf
+ '	+ ''[machineIP] [nvarchar] (16) NOT NULL,''' + @crlf
+ '	+ ''[sessionID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[lockDate] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[lockType] [int] NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- talkConfiguration' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[talkConfiguration] (''' + @crlf
+ '	+ ''[configurationID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[configurationData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lastModified] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[revision] [nvarchar](50) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @ProjectName + ''].[dbo].[talkConfiguration] WITH NOCHECK ADD CONSTRAINT [PK_talkConfiguration] PRIMARY KEY CLUSTERED ([configurationID]) ON [PRIMARY];'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- talkPosts' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[talkPosts] (''' + @crlf
+ '	+ ''[postID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[applicationID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[lessonID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[sbid] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[postData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[status] [int] NOT NULL,''' + @crlf
+ '	+ ''[lastModified] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[revision] [nvarchar](50) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @ProjectName + ''].[dbo].[talkPosts] WITH NOCHECK ADD CONSTRAINT [PK_talkPosts] PRIMARY KEY NONCLUSTERED ([postID]) ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE CLUSTERED INDEX [IX_applicationID-lessonID] ON ['' + @ProjectName + ''].[dbo].[talkPosts]([applicationID], [lessonID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE INDEX [IX_applicationID] ON ['' + @ProjectName + ''].[dbo].[talkPosts]([applicationID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE INDEX [IX_lessonID] ON ['' + @ProjectName + ''].[dbo].[talkPosts]([lessonID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE INDEX [IX_applicationID-lessonID-sbid] ON ['' + @ProjectName + ''].[dbo].[talkPosts]([applicationID], [lessonID], [sbid]) WITH FILLFACTOR = 80 ON [PRIMARY];'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- talkComments' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @ProjectName + ''].[dbo].[talkComments] (''' + @crlf
+ '	+ ''[commentID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[postID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[commentData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lastModified] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[revision] [nvarchar](50) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @ProjectName + ''].[dbo].[talkComments] WITH NOCHECK ADD CONSTRAINT [PK_talkComments] PRIMARY KEY NONCLUSTERED ([commentID]) ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE CLUSTERED INDEX [IX_postID] ON ['' + @ProjectName + ''].[dbo].[talkComments]([postID]) WITH FILLFACTOR = 80 ON [PRIMARY]'';' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- content database login' + @crlf
+ '--' + @crlf
+ '-- we''ll create the login if it doesn''t exist, and then go through the' + @crlf
+ '-- tables adding the appropriate rights' + @crlf
+ '--' + @crlf
+ '-- note that we allow ALTER permissions for the impressionAutonumbers' + @crlf
+ '-- table.  this is done so that we can reset the identity seed value; ' + @crlf
+ '-- this may be required if data is transferred from an existing content' + @crlf
+ '-- database.' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ '-- create the login as needed, then set permissions' + @crlf
+ '--' + @crlf
+ 'IF NOT EXISTS(SELECT name FROM master.sys.server_principals WHERE name = @SQLLoginName) BEGIN' + @crlf
+ '	SET @cSQL = ''CREATE LOGIN '' + @SQLLoginName + '' WITH PASSWORD = '''''' + @SQLLoginNamePassword + '''''', DEFAULT_DATABASE = ['' + @ProjectName + ''];'';' + @crlf
+ '	EXECUTE(@cSQL);' + @crlf
+ 'END' + @crlf
+ @crlf
+ 'SET @cSQL = ''USE '' + @ProjectName + '';''' + @crlf
+ '	+ '' EXECUTE sp_grantdbaccess N'''''' + @SQLLoginName + '''''', N'''''' + @SQLLoginName + '''''';''' + @crlf
+ '	+ '' GRANT ALTER, SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionAutonumbers] TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionLessons] TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionMilestones] TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionProjectProperties] TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionUserLocks] TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkConfiguration]  TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkPosts] TO '' + @SQLLoginName + '';''' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkComments] TO '' + @SQLLoginName + '';''' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- processing complete' + @crlf

SET @execSQL = 'USE [' + @ConnectorDBName + ']; EXECUTE (''' + REPLACE(@cSQL, '''', '''''') + ''')';
EXECUTE(@execSQL);


--
-- creating proc_NewImpressionDBFromConsole stored procedure
--
--
PRINT 'creating proc_NewImpressionDBFromConsole';

SET @cSQL = CAST('' AS nvarchar(max))
+ 'CREATE PROCEDURE [dbo].[proc_NewImpressionDBFromConsole](@DatabaseName nvarchar(50), @LoginName nvarchar(50), @LoginPassword as nvarchar(50)) AS' + @crlf
+ '-- proc_NewImpressionDBFromConsole' + @crlf
+ '--' + @crlf
+ '-- Impression Learning Content Framework' + @crlf
+ '-- Copyright 2006-2016 Logicdriven, LLC.  All rights reserved.' + @crlf
+ '--' + @crlf
+ '-- This procedure creates a new Impression-format content database.  It is intended' + @crlf
+ '-- to be run from SQL Server Management Studio.  The procedure only creates the database' + @crlf
+ '-- (and the login, if needed) - it does not add references to the database into the' + @crlf
+ '-- connector.' + @crlf
+ '--' + @crlf
+ '-- PARAMETERS:' + @crlf
+ '--     @DatabaseName  - name of the new database' + @crlf
+ '--     @LoginName     - name of the login to use to access the database.  if the user' + @crlf
+ '--                      does not exist, it will be created' + @crlf
+ '--     @LoginPassword - password for @LoginName' + @crlf
+ '--' + @crlf
+ '-- NOTES:' + @crlf
+ '--     - This procedure must be run with Administrator rights.' + @crlf
+ '--     - The ''sa'' account is incompatible with certain system procs.  ' + @crlf
+ '--       DO NOT use the ''sa'' account as the @LoginName parameter.' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ 'PRINT ''Execution started'';' + @crlf
+ 'PRINT '' '';' + @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- initial prep. validate parameters, then create the database' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ 'SET NOCOUNT ON' + @crlf
+ 'DECLARE @cSQL nvarchar(max);' + @crlf
+ 'DECLARE @crlf nvarchar(2);' + @crlf
+ 'SET @crlf = CHAR(13) + CHAR(10);' + @crlf
+ @crlf
+ 'IF (LEN(LTRIM(@DatabaseName)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''Database name cannot be blank.'', 16, 1);' + @crlf
+ '	RETURN;' + @crlf
+ 'END' + @crlf
+ 'IF (LEN(LTRIM(@LoginName)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''Login name cannot be blank.'', 16, 1);' + @crlf
+ '	RETURN;' + @crlf
+ 'END' + @crlf
+ @crlf
+ 'IF (LEN(LTRIM(@LoginPassword)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''Login password cannot be blank.'', 16, 1);' + @crlf
+ '	RETURN;' + @crlf
+ 'END' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ 'SET @cSQL = ''CREATE DATABASE ['' + @DatabaseName + '']'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- create content database structure' + @crlf
+ '--' + @crlf
+ '-- after creating the database, we now go through table by table, adding' + @crlf
+ '-- the columns, keys, and indexes for each one' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ '-- impressionAutonumbers' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[impressionAutonumbers] (''' + @crlf
+ '	+ ''[nextNumber] [int] IDENTITY (1, 1) NOT NULL,''' + @crlf
+ '	+ ''[ignored] [int] NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionLessons' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[impressionLessons] (''' + @crlf
+ '	+ ''[lessonID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[lessonTitle] [nvarchar] (255) NOT NULL,''' + @crlf
+ '	+ ''[lessonIdentifier] [nvarchar] (255) NOT NULL,''' + @crlf
+ '	+ ''[parentID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[indentLevel] [int] NOT NULL,''' + @crlf
+ '	+ ''[sortPosition] [int] NOT NULL,''' + @crlf
+ '	+ ''[lessonType] [int] NOT NULL,''' + @crlf
+ '	+ ''[lessonProperties] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lessonData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[guideData] [nvarchar](max) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @DatabaseName + ''].[dbo].[impressionLessons] WITH NOCHECK ADD CONSTRAINT [PK_impressionLessons] PRIMARY KEY CLUSTERED ([lessonID]) ON [PRIMARY];'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionMilestones' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[impressionMilestones] (''' + @crlf
+ '	+ ''[milestoneID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[lessonID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[savedBy] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[savedDate] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[milestoneProperties] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lessonData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[guideData] [nvarchar](max) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @DatabaseName + ''].[dbo].[impressionMilestones] ADD CONSTRAINT [PK_impressionMilestones] PRIMARY KEY NONCLUSTERED ([milestoneID]) ON [PRIMARY];'' + @crlf' + @crlf
+ '	+ ''CREATE CLUSTERED INDEX [IX_lessonID-milestoneID] ON ['' + @DatabaseName + ''].[dbo].[impressionMilestones]([lessonID], [milestoneID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' + @crlf' + @crlf
+ '	+ ''CREATE INDEX [IX_milestoneID-lessonID] ON ['' + @DatabaseName + ''].[dbo].[impressionMilestones]([milestoneID], [lessonID]) WITH FILLFACTOR = 80 ON [PRIMARY];'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionProjectProperties' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[impressionProjectProperties] (''' + @crlf
+ '	+ ''[propertyData] [nvarchar](max) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- impressionUserLocks' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[impressionUserLocks] (''' + @crlf
+ '	+ ''[lessonID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[username] [nvarchar] (32) NOT NULL,''' + @crlf
+ '	+ ''[machineName] [nvarchar] (32) NOT NULL,''' + @crlf
+ '	+ ''[machineIP] [nvarchar] (16) NOT NULL,''' + @crlf
+ '	+ ''[sessionID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[lockDate] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[lockType] [int] NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- talkConfiguration' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[talkConfiguration] (''' + @crlf
+ '	+ ''[configurationID] [nvarchar] (50) NOT NULL,''' + @crlf
+ '	+ ''[configurationData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lastModified] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[revision] [nvarchar](50) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @DatabaseName + ''].[dbo].[talkConfiguration] WITH NOCHECK ADD CONSTRAINT [PK_talkConfiguration] PRIMARY KEY CLUSTERED ([configurationID]) ON [PRIMARY];'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- talkPosts' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[talkPosts] (''' + @crlf
+ '	+ ''[postID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[applicationID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[lessonID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[sbid] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[postData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[status] [int] NOT NULL,''' + @crlf
+ '	+ ''[lastModified] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[revision] [nvarchar](50) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @DatabaseName + ''].[dbo].[talkPosts] WITH NOCHECK ADD CONSTRAINT [PK_talkPosts] PRIMARY KEY NONCLUSTERED ([postID]) ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE CLUSTERED INDEX [IX_applicationID-lessonID] ON ['' + @DatabaseName + ''].[dbo].[talkPosts]([applicationID], [lessonID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE INDEX [IX_applicationID] ON ['' + @DatabaseName + ''].[dbo].[talkPosts]([applicationID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE INDEX [IX_lessonID] ON ['' + @DatabaseName + ''].[dbo].[talkPosts]([lessonID]) WITH FILLFACTOR = 80 ON [PRIMARY];'' ' + @crlf
+ '	+ ''CREATE INDEX [IX_applicationID-lessonID-sbid] ON ['' + @DatabaseName + ''].[dbo].[talkPosts]([applicationID], [lessonID], [sbid]) WITH FILLFACTOR = 80 ON [PRIMARY];'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ '-- talkComments' + @crlf
+ '--' + @crlf
+ 'SET @cSQL = ''CREATE TABLE ['' + @DatabaseName + ''].[dbo].[talkComments] (''' + @crlf
+ '	+ ''[commentID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[postID] [nvarchar](50) NOT NULL,''' + @crlf
+ '	+ ''[commentData] [nvarchar](max) NOT NULL,''' + @crlf
+ '	+ ''[lastModified] [datetime] NOT NULL,''' + @crlf
+ '	+ ''[revision] [nvarchar](50) NOT NULL''' + @crlf
+ '	+ '') ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'SET @cSQL = ''ALTER TABLE ['' + @DatabaseName + ''].[dbo].[talkComments] WITH NOCHECK ADD CONSTRAINT [PK_talkComments] PRIMARY KEY NONCLUSTERED ([commentID]) ON [PRIMARY];'' + @crlf' + @crlf
+ '	+ ''CREATE CLUSTERED INDEX [IX_postID] ON ['' + @DatabaseName + ''].[dbo].[talkComments]([postID]) WITH FILLFACTOR = 80 ON [PRIMARY]'';' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- content database login' + @crlf
+ '--' + @crlf
+ '-- we''ll create the login if it doesn''t exist, and then go through the' + @crlf
+ '-- tables adding the appropriate rights' + @crlf
+ '--' + @crlf
+ '-- note that we allow ALTER permissions for the impressionAutonumbers' + @crlf
+ '-- table.  this is done so that we can reset the identity seed value; ' + @crlf
+ '-- this may be required if data is transferred from an existing content' + @crlf
+ '-- database.' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ '-- create the login as needed, then set permissions' + @crlf
+ '--' + @crlf
+ 'IF NOT EXISTS(SELECT name FROM master.sys.server_principals WHERE name = @LoginName) BEGIN' + @crlf
+ '	SET @cSQL = ''CREATE LOGIN '' + @LoginName + '' WITH PASSWORD = '''''' + @LoginPassword + '''''', DEFAULT_DATABASE = ['' + @DatabaseName + ''];'';' + @crlf
+ '	PRINT @cSQL;' + @crlf
+ '	EXECUTE(@cSQL);' + @crlf
+ 'END' + @crlf
+ @crlf
+ 'SET @cSQL = ''USE '' + @DatabaseName + '';'' + @crlf' + @crlf
+ '	+ '' EXECUTE sp_grantdbaccess N'''''' + @LoginName + '''''';'' + @crlf' + @crlf
+ '	+ '' GRANT ALTER, SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionAutonumbers] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionLessons] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionMilestones] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionProjectProperties] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionUserLocks] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkConfiguration]  TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkPosts] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkComments] TO '' + @LoginName + '';''' + @crlf
+ 'PRINT @cSQL;' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '-- processing complete' + @crlf
+ '--' + @crlf
+ 'PRINT '' '';' + @crlf
+ 'PRINT '' '';' + @crlf
+ 'PRINT ''Execution complete.'';' + @crlf
+ 'PRINT '' '';' + @crlf
+ 'PRINT ''The Impression content database '''''' + @DatabaseName + '''''' has been created.'';' + @crlf
+ 'PRINT ''Login '''''' + @LoginName + '''''' has been granted access to the database.'';' + @crlf
+ 'PRINT '' '';' + @crlf
+ 'PRINT ''Please set up a maintenance plan to safeguard your data.'';' + @crlf

SET @execSQL = 'USE [' + @ConnectorDBName + ']; EXECUTE (''' + REPLACE(@cSQL, '''', '''''') + ''')';
EXECUTE(@execSQL);


--
-- create proc_SetImpressionDBAccessRights stored procedure
--
--
PRINT 'creating proc_SetImpressionDBAccessRights';

SET @cSQL = CAST('' AS nvarchar(max))
+ 'CREATE PROCEDURE [dbo].[proc_SetImpressionDBAccessRights](@DatabaseName nvarchar(50), @LoginName nvarchar(50), @LoginPassword as nvarchar(50) = '''', @CreateLogin bit = 0) AS' + @crlf
+ '-- ' + @crlf
+ '-- proc_SetImpressionDBAccessRights' + @crlf
+ '--' + @crlf
+ '-- Impression Learning Content Framework' + @crlf
+ '-- Copyright 2013-2016 Logicdriven, LLC.  All rights reserved.' + @crlf
+ '--' + @crlf
+ '-- This procedure sets access rights to an existing Impression-format content' + @crlf
+ '-- database for the specified login.' + @crlf
+ '--' + @crlf
+ '-- PARAMETERS:' + @crlf
+ '--     @DatabaseName  - name of the content database to set permissions to.' + @crlf
+ '--     @LoginName     - name of the login to set permissions of.' + @crlf
+ '--     @LoginPassword - password for @LoginName.  This can be omitted if @LoginName' + @crlf
+ '--                      already exists.' + @crlf
+ '--     @CreateLogin   - True (1) if the login should be created if it doesn''t' + @crlf
+ '--                      already exist, or 0 if it should not be created.' + @crlf
+ '--                    ' + @crlf
+ '--' + @crlf
+ '-- NOTES:' + @crlf
+ '--     - This procedure must be run with Administrator rights.' + @crlf
+ '--     - The ''sa'' account is incompatible with certain system procs.  ' + @crlf
+ '--       DO NOT use the ''sa'' account as the @LoginName parameter.' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ '--' + @crlf
+ @crlf
+ @crlf
+ 'PRINT ''Execution started'';' + @crlf
+ 'PRINT '' '';' + @crlf
+ '--' + @crlf
+ '-- initial prep - declare locals, validate parameters' + @crlf
+ '--' + @crlf
+ 'SET NOCOUNT ON ' + @crlf
+ 'DECLARE @cSQL nvarchar(max);' + @crlf
+ 'DECLARE @crlf nvarchar(2);' + @crlf
+ 'SET @crlf = CHAR(13) + CHAR(10);' + @crlf
+ @crlf
+ @crlf
+ 'PRINT ''Validating parameters'';' + @crlf
+ @crlf
+ 'IF (LEN(LTRIM(@DatabaseName)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''No database name passed.'', 16, 1);' + @crlf
+ '	PRINT ''Execution stopped with error.'';' + @crlf
+ '	RETURN;' + @crlf
+ 'END;' + @crlf
+ @crlf
+ 'IF NOT EXISTS(SELECT name FROM master.sys.databases WHERE name = @DatabaseName) BEGIN' + @crlf
+ '	RAISERROR (''Database not found.'', 16, 1);' + @crlf
+ '	PRINT ''Execution stopped with error.'';' + @crlf
+ '	RETURN;' + @crlf
+ 'END;' + @crlf
+ @crlf
+ 'IF (LEN(LTRIM(@LoginName)) = 0) BEGIN' + @crlf
+ '	RAISERROR (''No login name passed.'', 16, 1);' + @crlf
+ '	PRINT ''Execution stopped with error.'';' + @crlf
+ '	RETURN;' + @crlf
+ 'END;' + @crlf
+ @crlf
+ 'IF NOT EXISTS(SELECT name FROM master.sys.server_principals WHERE name = @LoginName) BEGIN' + @crlf
+ '-- login doesn''t exist.  ensure we have a password and permission to create' + @crlf
+ '	IF (@CreateLogin = 0) BEGIN' + @crlf
+ '		RAISERROR (''Login name not found, and @CreateLogin parameter set to False/0.'', 16, 1);' + @crlf
+ '		PRINT ''Execution stopped with error.'';' + @crlf
+ '		RETURN;' + @crlf
+ '	END;' + @crlf
+ '	IF (LEN(LTRIM(@LoginPassword)) = 0) BEGIN' + @crlf
+ '		RAISERROR (''Password cannot be blank when login does not exist.'', 16, 1);' + @crlf
+ '		PRINT ''Execution stopped with error.'';' + @crlf
+ '		RETURN;' + @crlf
+ '	END;' + @crlf
+ 'END;' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '--' + @crlf
+ '-- create the login as needed, and set permissions' + @crlf
+ '--' + @crlf
+ 'IF NOT EXISTS(SELECT name FROM master.sys.server_principals WHERE name = @LoginName) BEGIN' + @crlf
+ '	PRINT ''Creating login '''''' + @LoginName + '''''''';' + @crlf
+ '	SET @cSQL = ''CREATE LOGIN '' + @LoginName + '' WITH PASSWORD = '''''' + @LoginPassword + '''''', DEFAULT_DATABASE = ['' + @DatabaseName + ''];'';' + @crlf
+ '	EXECUTE(@cSQL);' + @crlf
+ 'END ELSE BEGIN' + @crlf
+ '	PRINT ''Login '''''' + @LoginName + '''''' already exists.  Skipping creation'';' + @crlf
+ 'END;' + @crlf
+ @crlf
+ @crlf
+ 'PRINT ''Granting database access'';' + @crlf
+ 'SET @cSQL = ''USE '' + @DatabaseName + '';'' + @crlf' + @crlf
+ '	+ '' EXECUTE sp_grantdbaccess N'''''' + @LoginName + '''''';''' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ 'PRINT ''Setting permissions'';' + @crlf
+ 'SET @cSQL = ''USE '' + @DatabaseName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT ALTER, SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionAutonumbers] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionLessons] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionMilestones] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionProjectProperties] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[impressionUserLocks] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkConfiguration]  TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkPosts] TO '' + @LoginName + '';'' + @crlf' + @crlf
+ '	+ '' GRANT SELECT, UPDATE, INSERT, DELETE ON [dbo].[talkComments] TO '' + @LoginName + '';''' + @crlf
+ 'EXECUTE(@cSQL);' + @crlf
+ @crlf
+ @crlf
+ @crlf
+ @crlf
+ '-- processing complete' + @crlf
+ '--' + @crlf
+ 'PRINT '' '';' + @crlf
+ 'PRINT ''Execution complete.'';' + @crlf
+ 'PRINT ''Login '''''' + @LoginName + '''''' has been granted rights to content database '''''' + @DatabaseName + ''''''.'';' + @crlf
+ @crlf

SET @execSQL = 'USE [' + @ConnectorDBName + ']; EXECUTE (''' + REPLACE(@cSQL, '''', '''''') + ''')';
EXECUTE(@execSQL);








PRINT ' ';
PRINT ' ';
PRINT 'Execution complete.';
PRINT ' ';
PRINT '*******************************************************************************';
PRINT 'The Impression connector database, ' + @ConnectorDBName + ', has been created.';
PRINT 'Please set up a maintenance plan to safeguard your Impression data.';
PRINT ' ';
PRINT 'Use the following settings in the CCT to access the connector:';
PRINT ' ';
PRINT '  Data Source: ''' + @@servername + '''';
PRINT '      Catalog: ''' + @ConnectorDBName + '''';
PRINT '     Username: ''' + @ConnectorUsername + '''';
PRINT '     Password: ''' + @ConnectorPassword + '''';
PRINT ' ';
PRINT '*******************************************************************************';


